@@ -105,7 +105,12 @@ class CommonBrowserView(BrowserView):
         return structure
     
     def getLeadMediaTag(self, item, scale="large"):
-        if hasattr(item, 'leadMedia'):
+        if item.portal_type == 'Image':
+            if hasattr(item, 'getURL'):
+                lead = item.getURL()
+            else:
+                lead = item.absolute_url()
+        elif hasattr(item, 'leadMedia'):
             lead = item.leadMedia
         else:
             catalog = getToolByName(self.context, 'portal_catalog')
@@ -134,6 +139,23 @@ class CommonBrowserView(BrowserView):
             else:
                 return False
     
+    def getPressKit(self, item):
+        if item.restrictedTraverse('@@plone').isStructuralFolder():
+            catalog = getToolByName(self.context, 'portal_catalog')
+            plone_utils = getToolByName(self.context, 'plone_utils')
+            path = '/'.join(item.getPhysicalPath())
+            sm = getSecurityManager() 
+            
+            results = catalog.searchResults(path = {'query' : path}, portal_type = 'Press Kit')
+            
+            for result in results:
+                if sm.checkPermission('View', result):
+                    return result
+            
+            return None
+        else:
+            return None
+    
     def trimText(self, text, limit, strip=False):
         if strip:
             text = self.stripTags(text)
@@ -379,7 +401,7 @@ class FolderListing(CommonBrowserView):
                results = Batch(final_res, pagesize, start=b_start)
             else:
                 return final_res
-        elif self.context.portal_type  == 'Folder':
+        elif self.context.portal_type  in ['Folder', 'Press Kit']:
             brains = self.context.getFolderContents()
             if only_documented:
                 final_res = []
